@@ -7,7 +7,7 @@
 
 #include <probes/lttng-tracepoint-event.h>
 #include <linux/writeback.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
 #ifndef _TRACE_EXT4_DEF_
 #define _TRACE_EXT4_DEF_
@@ -17,13 +17,13 @@ struct ext4_prealloc_space;
 struct ext4_inode_info;
 struct mpage_da_data;
 struct ext4_map_blocks;
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 struct ext4_extent;
 #endif
 #endif
 
 #define EXT4_I(inode) (container_of(inode, struct ext4_inode_info, vfs_inode))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
 #define TP_MODE_T	__u16
 #else
 #define TP_MODE_T	umode_t
@@ -37,7 +37,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_free_inode,
 	TP_FIELDS(
 		ctf_integer(dev_t, dev, inode->i_sb->s_dev)
 		ctf_integer(ino_t, ino, inode->i_ino)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,5,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,5,0))
 		ctf_integer(uid_t, uid, i_uid_read(inode))
 		ctf_integer(gid_t, gid, i_gid_read(inode))
 #else
@@ -74,7 +74,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_allocate_inode,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 LTTNG_TRACEPOINT_EVENT(ext4_evict_inode,
 	TP_PROTO(struct inode *inode),
 
@@ -122,7 +121,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_begin_ordered_truncate,
 		ctf_integer(loff_t, new_size, new_size)
 	)
 )
-#endif
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__write_begin,
 
@@ -203,20 +201,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__write_end, ext4_da_write_end,
 	TP_ARGS(inode, pos, len, copied)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,40))
-LTTNG_TRACEPOINT_EVENT(ext4_writepage,
-	TP_PROTO(struct inode *inode, struct page *page),
-
-	TP_ARGS(inode, page),
-
-	TP_FIELDS(
-		ctf_integer(dev_t, dev, inode->i_sb->s_dev)
-		ctf_integer(ino_t, ino, inode->i_ino)
-		ctf_integer(pgoff_t, index, page->index)
-	)
-)
-#endif
-
 LTTNG_TRACEPOINT_EVENT(ext4_da_writepages,
 	TP_PROTO(struct inode *inode, struct writeback_control *wbc),
 
@@ -230,21 +214,13 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_writepages,
 		ctf_integer(loff_t, range_start, wbc->range_start)
 		ctf_integer(loff_t, range_end, wbc->range_end)
 		ctf_integer(pgoff_t, writeback_index, inode->i_mapping->writeback_index)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(int, sync_mode, wbc->sync_mode)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,37))
-		ctf_integer(char, nonblocking, wbc->nonblocking)
-#endif
 		ctf_integer(char, for_kupdate, wbc->for_kupdate)
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,39))
-		ctf_integer(char, for_reclaim, wbc->for_reclaim)
-#endif
 		ctf_integer(char, range_cyclic, wbc->range_cyclic)
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_da_write_pages,
 	TP_PROTO(struct inode *inode, pgoff_t first_page,
@@ -277,15 +253,13 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_write_pages,
 		ctf_integer(unsigned long, first_page, mpd->first_page)
 		ctf_integer(int, io_done, mpd->io_done)
 		ctf_integer(int, pages_written, mpd->pages_written)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(int, sync_mode, mpd->wbc->sync_mode)
-#endif
 	)
 )
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_da_write_pages_extent,
 	TP_PROTO(struct inode *inode, struct ext4_map_blocks *map),
@@ -316,22 +290,10 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_writepages_result,
 		ctf_integer(int, pages_written, pages_written)
 		ctf_integer(long, pages_skipped, wbc->pages_skipped)
 		ctf_integer(pgoff_t, writeback_index, inode->i_mapping->writeback_index)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(int, sync_mode, wbc->sync_mode)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,33))
-		ctf_integer(char, encountered_congestion, wbc->encountered_congestion)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
-		ctf_integer(char, more_io, wbc->more_io)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,35))
-		ctf_integer(char, no_nrwrite_index_update, wbc->no_nrwrite_index_update)
-#endif
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__page_op,
 	TP_PROTO(struct page *page),
 
@@ -344,14 +306,12 @@ LTTNG_TRACEPOINT_EVENT_CLASS(ext4__page_op,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,40))
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__page_op, ext4_writepage,
 
 	TP_PROTO(struct page *page),
 
 	TP_ARGS(page)
 )
-#endif
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__page_op, ext4_readpage,
 
@@ -367,7 +327,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__page_op, ext4_releasepage,
 	TP_ARGS(page)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4_invalidatepage_op,
 	TP_PROTO(struct page *page, unsigned int offset, unsigned int length),
@@ -413,8 +373,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_invalidatepage,
 
 #endif
 
-#endif
-
 LTTNG_TRACEPOINT_EVENT(ext4_discard_blocks,
 	TP_PROTO(struct super_block *sb, unsigned long long blk,
 			unsigned long long count),
@@ -461,107 +419,47 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__mb_new_pa, ext4_mb_new_group_pa,
 
 LTTNG_TRACEPOINT_EVENT(ext4_mb_release_inode_pa,
 	TP_PROTO(
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,40))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
-		 struct super_block *sb,
-		 struct inode *inode,
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
-		 struct super_block *sb,
-		 struct ext4_allocation_context *ac,
-#else
-		 struct ext4_allocation_context *ac,
-#endif
-#endif
 		 struct ext4_prealloc_space *pa,
 		 unsigned long long block, unsigned int count),
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,40))
 	TP_ARGS(pa, block, count),
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
-	TP_ARGS(sb, inode, pa, block, count),
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
-	TP_ARGS(sb, ac, pa, block, count),
-#else
-	TP_ARGS(ac, pa, block, count),
-#endif
 
 	TP_FIELDS(
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,40))
 		ctf_integer(dev_t, dev, pa->pa_inode->i_sb->s_dev)
 		ctf_integer(ino_t, ino, pa->pa_inode->i_ino)
-#else
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
-		ctf_integer(dev_t, dev, sb->s_dev)
-#else
-		ctf_integer(dev_t, dev, ac->ac_sb->s_dev)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
-		ctf_integer(ino_t, ino, inode->i_ino)
-#else
-		ctf_integer(ino_t, ino,
-			(ac && ac->ac_inode) ? ac->ac_inode->i_ino : 0)
-#endif
-#endif
 		ctf_integer(__u64, block, block)
 		ctf_integer(__u32, count, count)
 	)
 )
 
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 LTTNG_TRACEPOINT_EVENT(ext4_mb_release_group_pa,
 
-#if (LTTNG_KERNEL_RANGE(2,6,40, 3,3,0))
-	TP_PROTO(struct ext4_prealloc_space *pa),
-
-	TP_ARGS(pa),
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 	TP_PROTO(struct super_block *sb, struct ext4_prealloc_space *pa),
 
 	TP_ARGS(sb, pa),
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
-	TP_PROTO(struct super_block *sb,
-		 struct ext4_allocation_context *ac,
-		 struct ext4_prealloc_space *pa),
-
-	TP_ARGS(sb, ac, pa),
-#else
-	TP_PROTO(struct ext4_allocation_context *ac,
-		 struct ext4_prealloc_space *pa),
-
-	TP_ARGS(ac, pa),
-#endif
 
 	TP_FIELDS(
-#if (LTTNG_KERNEL_RANGE(2,6,40, 3,3,0))
-		ctf_integer(dev_t, dev, pa->pa_inode->i_sb->s_dev)
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 		ctf_integer(dev_t, dev, sb->s_dev)
-#else
-		ctf_integer(dev_t, dev, ac->ac_sb->s_dev)
-#endif
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,37))
-		ctf_integer(ino_t, ino,
-			(ac && ac->ac_inode) ? ac->ac_inode->i_ino : 0)
-#endif
 		ctf_integer(__u64, pa_pstart, pa->pa_pstart)
 		ctf_integer(__u32, pa_len, pa->pa_len)
 	)
 )
+#else
+LTTNG_TRACEPOINT_EVENT(ext4_mb_release_group_pa,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0) || \
-	LTTNG_KERNEL_RANGE(5,8,6, 5,9,0))
-LTTNG_TRACEPOINT_EVENT(ext4_discard_preallocations,
-	TP_PROTO(struct inode *inode, unsigned int len, unsigned int needed),
+	TP_PROTO(struct ext4_prealloc_space *pa),
 
-	TP_ARGS(inode, len, needed),
+	TP_ARGS(pa),
 
 	TP_FIELDS(
-		ctf_integer(dev_t, dev, inode->i_sb->s_dev)
-		ctf_integer(ino_t, ino, inode->i_ino)
-		ctf_integer(unsigned int, len, len)
-		ctf_integer(unsigned int, needed, needed)
+		ctf_integer(dev_t, dev, pa->pa_inode->i_sb->s_dev)
+		ctf_integer(__u64, pa_pstart, pa->pa_pstart)
+		ctf_integer(__u32, pa_len, pa->pa_len)
 	)
 )
-#else
+#endif
+
 LTTNG_TRACEPOINT_EVENT(ext4_discard_preallocations,
 	TP_PROTO(struct inode *inode),
 
@@ -572,7 +470,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_discard_preallocations,
 		ctf_integer(ino_t, ino, inode->i_ino)
 	)
 )
-#endif
 
 LTTNG_TRACEPOINT_EVENT(ext4_mb_discard_preallocations,
 	TP_PROTO(struct super_block *sb, int needed),
@@ -625,62 +522,34 @@ LTTNG_TRACEPOINT_EVENT(ext4_allocate_blocks,
 )
 
 LTTNG_TRACEPOINT_EVENT(ext4_free_blocks,
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 	TP_PROTO(struct inode *inode, __u64 block, unsigned long count,
 		 int flags),
 
 	TP_ARGS(inode, block, count, flags),
-#else
-	TP_PROTO(struct inode *inode, __u64 block, unsigned long count,
-		 int metadata),
-
-	TP_ARGS(inode, block, count, metadata),
-#endif
 
 	TP_FIELDS(
 		ctf_integer(dev_t, dev, inode->i_sb->s_dev)
 		ctf_integer(ino_t, ino, inode->i_ino)
 		ctf_integer(__u64, block, block)
 		ctf_integer(unsigned long, count, count)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 		ctf_integer(int, flags, flags)
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
-#else
-		ctf_integer(int, metadata, metadata)
-#endif
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 LTTNG_TRACEPOINT_EVENT(ext4_sync_file_enter,
-#else
-LTTNG_TRACEPOINT_EVENT(ext4_sync_file,
-#endif
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 	TP_PROTO(struct file *file, int datasync),
 
 	TP_ARGS(file, datasync),
-#else
-	TP_PROTO(struct file *file, struct dentry *dentry, int datasync),
-
-	TP_ARGS(file, dentry, datasync),
-#endif
 
 	TP_FIELDS(
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 		ctf_integer(dev_t, dev, file->f_path.dentry->d_inode->i_sb->s_dev)
 		ctf_integer(ino_t, ino, file->f_path.dentry->d_inode->i_ino)
 		ctf_integer(ino_t, parent, file->f_path.dentry->d_parent->d_inode->i_ino)
-#else
-		ctf_integer(dev_t, dev, dentry->d_inode->i_sb->s_dev)
-		ctf_integer(ino_t, ino, dentry->d_inode->i_ino)
-		ctf_integer(ino_t, parent, dentry->d_parent->d_inode->i_ino)
-#endif
 		ctf_integer(int, datasync, datasync)
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 LTTNG_TRACEPOINT_EVENT(ext4_sync_file_exit,
 	TP_PROTO(struct inode *inode, int ret),
 
@@ -692,7 +561,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_sync_file_exit,
 		ctf_integer(int, ret, ret)
 	)
 )
-#endif
 
 LTTNG_TRACEPOINT_EVENT(ext4_sync_fs,
 	TP_PROTO(struct super_block *sb, int wait),
@@ -706,7 +574,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_sync_fs,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,13,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,13,0))
 LTTNG_TRACEPOINT_EVENT(ext4_alloc_da_blocks,
 	TP_PROTO(struct inode *inode),
 
@@ -782,7 +650,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_mballoc_prealloc,
 )
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__mballoc,
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 	TP_PROTO(struct super_block *sb,
 		 struct inode *inode,
 		 ext4_group_t group,
@@ -790,33 +657,18 @@ LTTNG_TRACEPOINT_EVENT_CLASS(ext4__mballoc,
 		 ext4_grpblk_t len),
 
 	TP_ARGS(sb, inode, group, start, len),
-#else
-	TP_PROTO(struct ext4_allocation_context *ac),
-
-	TP_ARGS(ac),
-#endif
 
 	TP_FIELDS(
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 		ctf_integer(dev_t, dev, sb->s_dev)
 		ctf_integer(ino_t, ino, inode ? inode->i_ino : 0)
 		ctf_integer(int, result_start, start)
 		ctf_integer(__u32, result_group, group)
 		ctf_integer(int, result_len, len)
-#else
-		ctf_integer(dev_t, dev, ac->ac_sb->s_dev)
-		ctf_integer(ino_t, ino, ac->ac_inode ? ac->ac_inode->i_ino : 0)
-		ctf_integer(__u32, result_logical, ac->ac_b_ex.fe_logical)
-		ctf_integer(int, result_start, ac->ac_b_ex.fe_start)
-		ctf_integer(__u32, result_group, ac->ac_b_ex.fe_group)
-		ctf_integer(int, result_len, ac->ac_b_ex.fe_len)
-#endif
 	)
 )
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__mballoc, ext4_mballoc_discard,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 	TP_PROTO(struct super_block *sb,
 		 struct inode *inode,
 		 ext4_group_t group,
@@ -824,16 +676,10 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__mballoc, ext4_mballoc_discard,
 		 ext4_grpblk_t len),
 
 	TP_ARGS(sb, inode, group, start, len)
-#else
-	TP_PROTO(struct ext4_allocation_context *ac),
-
-	TP_ARGS(ac)
-#endif
 )
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__mballoc, ext4_mballoc_free,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 	TP_PROTO(struct super_block *sb,
 		 struct inode *inode,
 		 ext4_group_t group,
@@ -841,14 +687,8 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__mballoc, ext4_mballoc_free,
 		 ext4_grpblk_t len),
 
 	TP_ARGS(sb, inode, group, start, len)
-#else
-	TP_PROTO(struct ext4_allocation_context *ac),
-
-	TP_ARGS(ac)
-#endif
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 LTTNG_TRACEPOINT_EVENT(ext4_forget,
 	TP_PROTO(struct inode *inode, int is_metadata, __u64 block),
 
@@ -862,9 +702,8 @@ LTTNG_TRACEPOINT_EVENT(ext4_forget,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,13,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,13,0))
 LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 	TP_PROTO(struct inode *inode, int used_blocks, int quota_claim),
 
@@ -881,7 +720,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 	TP_PROTO(struct inode *inode, int used_blocks, int quota_claim),
 
@@ -902,7 +741,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,34))
+#else
 LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 	TP_PROTO(struct inode *inode, int used_blocks),
 
@@ -924,7 +763,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_update_reserve_space,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,13,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,13,0))
 LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 	TP_PROTO(struct inode *inode),
 
@@ -939,7 +778,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0))
 LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 	TP_PROTO(struct inode *inode),
 
@@ -956,7 +795,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,34))
+#else
 LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 	TP_PROTO(struct inode *inode, int md_needed),
 
@@ -976,7 +815,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_reserve_space,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,13,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,13,0))
 LTTNG_TRACEPOINT_EVENT(ext4_da_release_space,
 	TP_PROTO(struct inode *inode, int freed_blocks),
 
@@ -992,7 +831,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_release_space,
 		ctf_integer(TP_MODE_T, mode, inode->i_mode)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,34))
+#else
 LTTNG_TRACEPOINT_EVENT(ext4_da_release_space,
 	TP_PROTO(struct inode *inode, int freed_blocks),
 
@@ -1014,7 +853,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_da_release_space,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,35))
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__bitmap_load,
 	TP_PROTO(struct super_block *sb, unsigned long group),
 
@@ -1039,30 +877,13 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__bitmap_load, ext4_mb_buddy_bitmap_load,
 
 	TP_ARGS(sb, group)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0))
-LTTNG_TRACEPOINT_EVENT(ext4_read_block_bitmap_load,
-	TP_PROTO(struct super_block *sb, unsigned long group, bool prefetch),
-
-	TP_ARGS(sb, group, prefetch),
-
-	TP_FIELDS(
-		ctf_integer(dev_t, dev, sb->s_dev)
-		ctf_integer(__u32, group, group)
-		ctf_integer(bool, prefetch, prefetch)
-	)
-)
-#else
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__bitmap_load, ext4_read_block_bitmap_load,
 
 	TP_PROTO(struct super_block *sb, unsigned long group),
 
 	TP_ARGS(sb, group)
 )
-#endif
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__bitmap_load, ext4_load_inode_bitmap,
 
@@ -1116,7 +937,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_fallocate_exit,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__fallocate_mode,
 	TP_PROTO(struct inode *inode, loff_t offset, loff_t len, int mode),
@@ -1153,7 +974,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__fallocate_mode, ext4_zero_range,
 	TP_ARGS(inode, offset, len, mode)
 )
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0)) */
 
 LTTNG_TRACEPOINT_EVENT(ext4_fallocate_enter,
 	TP_PROTO(struct inode *inode, loff_t offset, loff_t len, int mode),
@@ -1169,7 +990,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_fallocate_enter,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_punch_hole,
 	TP_PROTO(struct inode *inode, loff_t offset, loff_t len),
@@ -1184,9 +1005,9 @@ LTTNG_TRACEPOINT_EVENT(ext4_punch_hole,
 	)
 )
 
-#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0)) */
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0)) */
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,15,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,15,0)) */
 
 LTTNG_TRACEPOINT_EVENT(ext4_unlink_enter,
 	TP_PROTO(struct inode *parent, struct dentry *dentry),
@@ -1239,7 +1060,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__truncate, ext4_truncate_exit,
 	TP_ARGS(inode)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 /* 'ux' is the uninitialized extent. */
 LTTNG_TRACEPOINT_EVENT(ext4_ext_convert_to_initialized_enter,
 	TP_PROTO(struct inode *inode, struct ext4_map_blocks *map,
@@ -1312,7 +1133,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__map_blocks_enter, ext4_ind_map_blocks_ente
 	TP_ARGS(inode, lblk, len, flags)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__map_blocks_exit,
 	TP_PROTO(struct inode *inode, unsigned flags, struct ext4_map_blocks *map,
@@ -1346,7 +1167,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__map_blocks_exit, ext4_ind_map_blocks_exit,
 	TP_ARGS(inode, flags, map, ret)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__map_blocks_exit,
 	TP_PROTO(struct inode *inode, struct ext4_map_blocks *map, int ret),
@@ -1376,7 +1197,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__map_blocks_exit, ext4_ind_map_blocks_exit,
 	TP_ARGS(inode, map, ret)
 )
 
-#else	/* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#else	/* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__map_blocks_exit,
 	TP_PROTO(struct inode *inode, ext4_lblk_t lblk,
@@ -1408,7 +1229,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__map_blocks_exit, ext4_ind_map_blocks_exit,
 	TP_ARGS(inode, lblk, pblk, len, ret)
 )
 
-#endif	/* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#endif	/* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_load_extent,
 	TP_PROTO(struct inode *inode, ext4_lblk_t lblk, ext4_fsblk_t pblk),
@@ -1423,18 +1244,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_load_extent,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,10,0))
-LTTNG_TRACEPOINT_EVENT(ext4_load_inode,
-	TP_PROTO(struct super_block *sb, unsigned long ino),
-
-	TP_ARGS(sb, ino),
-
-	TP_FIELDS(
-		ctf_integer(dev_t, dev, sb->s_dev)
-		ctf_integer(ino_t, ino, ino)
-	)
-)
-#else
 LTTNG_TRACEPOINT_EVENT(ext4_load_inode,
 	TP_PROTO(struct inode *inode),
 
@@ -1445,10 +1254,8 @@ LTTNG_TRACEPOINT_EVENT(ext4_load_inode,
 		ctf_integer(ino_t, ino, inode->i_ino)
 	)
 )
-#endif
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,5,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,5,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_journal_start,
 	TP_PROTO(struct super_block *sb, int blocks, int rsv_blocks,
@@ -1477,7 +1284,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_journal_start_reserved,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_journal_start,
 	TP_PROTO(struct super_block *sb, int blocks, int rsv_blocks,
@@ -1505,7 +1312,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_journal_start_reserved,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_journal_start,
 	TP_PROTO(struct super_block *sb, int nblocks, unsigned long IP),
@@ -1557,29 +1364,29 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__trim, ext4_trim_all_free,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_handle_uninitialized_extents,
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
 	TP_PROTO(struct inode *inode, struct ext4_map_blocks *map, int flags,
 		 unsigned int allocated, ext4_fsblk_t newblock),
 
 	TP_ARGS(inode, map, flags, allocated, newblock),
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 	TP_PROTO(struct inode *inode, struct ext4_map_blocks *map,
 		 unsigned int allocated, ext4_fsblk_t newblock),
 
 	TP_ARGS(inode, map, allocated, newblock),
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 
 	TP_FIELDS(
 		ctf_integer(dev_t, dev, inode->i_sb->s_dev)
 		ctf_integer(ino_t, ino, inode->i_ino)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0))
 		ctf_integer(int, flags, flags)
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 		ctf_integer(int, flags, map->m_flags)
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)) */
 		ctf_integer(ext4_lblk_t, lblk, map->m_lblk)
 		ctf_integer(ext4_fsblk_t, pblk, map->m_pblk)
 		ctf_integer(unsigned int, len, map->m_len)
@@ -1676,7 +1483,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_show_extent,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,20,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,20,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,147,0,0, 4,19,0,0,0,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_remove_blocks,
@@ -1700,7 +1507,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_remove_blocks,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_remove_blocks,
 	    TP_PROTO(struct inode *inode, struct ext4_extent *ex,
@@ -1744,7 +1551,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_remove_blocks,
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,20,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,20,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,147,0,0, 4,19,0,0,0,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_rm_leaf,
@@ -1767,7 +1574,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_rm_leaf,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_rm_leaf,
 	TP_PROTO(struct inode *inode, ext4_lblk_t start,
@@ -1820,7 +1627,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_rm_idx,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space,
 	TP_PROTO(struct inode *inode, ext4_lblk_t start,
@@ -1854,7 +1661,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space,
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,20,0) || \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,20,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,147,0,0, 4,19,0,0,0,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space_done,
@@ -1876,7 +1683,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space_done,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space_done,
 	TP_PROTO(struct inode *inode, ext4_lblk_t start, ext4_lblk_t end,
@@ -1917,7 +1724,7 @@ LTTNG_TRACEPOINT_EVENT(ext4_ext_remove_space_done,
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(ext4__es_extent,
 	TP_PROTO(struct inode *inode, struct extent_status *es),
@@ -1946,7 +1753,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(ext4__es_extent, ext4_es_cache_extent,
 	TP_ARGS(inode, es)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,11,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,11,0))
 
 LTTNG_TRACEPOINT_EVENT(ext4_es_insert_extent,
 	TP_PROTO(struct inode *inode, struct extent_status *es),
@@ -2058,34 +1865,6 @@ LTTNG_TRACEPOINT_EVENT(ext4_es_shrink_exit,
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,10,0))
-LTTNG_TRACEPOINT_EVENT(ext4_fc_replay_scan,
-	TP_PROTO(struct super_block *sb, int error, int off),
-
-	TP_ARGS(sb, error, off),
-
-	TP_FIELDS(
-		ctf_integer(dev_t, dev, sb->s_dev)
-		ctf_integer(int, error, error)
-		ctf_integer(int, off, off)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT(ext4_fc_replay,
-	TP_PROTO(struct super_block *sb, int tag, int ino, int priv1, int priv2),
-
-	TP_ARGS(sb, tag, ino, priv1, priv2),
-
-	TP_FIELDS(
-		ctf_integer(dev_t, dev, sb->s_dev)
-		ctf_integer(int, tag, tag)
-		ctf_integer(int, ino, ino)
-		ctf_integer(int, priv1, priv1)
-		ctf_integer(int, priv2, priv2)
-	)
-)
-#endif
-
 #endif /* LTTNG_TRACE_EXT4_H */
 
 /* This part must be outside protection */
