@@ -3,13 +3,11 @@
 #define LTTNG_TRACE_KVM_MAIN_H
 
 #include <probes/lttng-tracepoint-event.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
 #undef TRACE_SYSTEM
 #define TRACE_SYSTEM kvm
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,38))
-
 LTTNG_TRACEPOINT_EVENT(kvm_userspace_exit,
 	    TP_PROTO(__u32 reason, int errno),
 	    TP_ARGS(reason, errno),
@@ -19,9 +17,8 @@ LTTNG_TRACEPOINT_EVENT(kvm_userspace_exit,
 		ctf_integer(int, errno, errno)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,6,0))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,6,0))
 #if defined(__KVM_HAVE_IOAPIC)
 #undef __KVM_HAVE_IRQ_LINE
 #define __KVM_HAVE_IRQ_LINE
@@ -101,7 +98,7 @@ LTTNG_TRACEPOINT_EVENT(kvm_mmio,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,15,0) \
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,15,0) \
 	|| LTTNG_KERNEL_RANGE(4,14,14, 4,15,0) \
 	|| LTTNG_DEBIAN_KERNEL_RANGE(4,14,13,0,1,0, 4,15,0,0,0,0) \
 	|| LTTNG_KERNEL_RANGE(4,9,77, 4,10,0) \
@@ -142,8 +139,6 @@ LTTNG_TRACEPOINT_EVENT(kvm_mmio,
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,34))
-
 #define kvm_fpu_load_symbol	\
 	{0, "unload"},		\
 	{1, "load"}
@@ -157,7 +152,7 @@ LTTNG_TRACEPOINT_EVENT(kvm_fpu,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,18,0) \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,18,0) \
 	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,327,0,0, 3,11,0,0,0,0))
 
 LTTNG_TRACEPOINT_EVENT(kvm_age_page,
@@ -187,9 +182,6 @@ LTTNG_TRACEPOINT_EVENT(kvm_age_page,
 	)
 )
 #endif
-#endif
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,38))
 
 #ifdef CONFIG_KVM_ASYNC_PF
 LTTNG_TRACEPOINT_EVENT_CLASS(kvm_async_get_page_class,
@@ -244,7 +236,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(kvm_async_pf_nopresent_ready, kvm_async_pf_ready
 	TP_ARGS(token, gva)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0) \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0) \
 	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,0,0, 3,11,0,0,0,0))
 
 LTTNG_TRACEPOINT_EVENT(
@@ -258,7 +250,7 @@ LTTNG_TRACEPOINT_EVENT(
 	)
 )
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0)) */
 
 LTTNG_TRACEPOINT_EVENT(
 	kvm_async_pf_completed,
@@ -272,9 +264,7 @@ LTTNG_TRACEPOINT_EVENT(
 	)
 )
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0)) */
-
-#endif
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0)) */
 
 #endif
 
