@@ -7,9 +7,8 @@
 
 #include <probes/lttng-tracepoint-event.h>
 #include <linux/ktime.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,38))
 LTTNG_TRACEPOINT_EVENT_CLASS(power_cpu,
 
 	TP_PROTO(unsigned int state, unsigned int cpu_id),
@@ -59,9 +58,8 @@ LTTNG_TRACEPOINT_EVENT_MAP(machine_suspend,
 		ctf_integer(u32, state, state)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,5,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,5,0))
 LTTNG_TRACEPOINT_EVENT_CLASS(power_wakeup_source,
 
 	TP_PROTO(const char *name, unsigned int state),
@@ -93,12 +91,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(power_wakeup_source, wakeup_source_deactivat
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,38))
-#undef CONFIG_EVENT_POWER_TRACING_DEPRECATED
-#define CONFIG_EVENT_POWER_TRACING_DEPRECATED
-#define _PWR_EVENT_AVOID_DOUBLE_DEFINING_DEPRECATED
-#endif
-
 #ifdef CONFIG_EVENT_POWER_TRACING_DEPRECATED
 
 /*
@@ -107,69 +99,39 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(power_wakeup_source, wakeup_source_deactivat
  */
 LTTNG_TRACEPOINT_EVENT_CLASS(power,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 	TP_PROTO(unsigned int type, unsigned int state, unsigned int cpu_id),
 
 	TP_ARGS(type, state, cpu_id),
-#else
-	TP_PROTO(unsigned int type, unsigned int state),
-
-	TP_ARGS(type, state),
-#endif
 
 	TP_FIELDS(
 		ctf_integer(u64, type, type)
 		ctf_integer(u64, state, state)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 		ctf_integer(u64, cpu_id, cpu_id)
-#endif
 	)
 )
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(power, power_start,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 	TP_PROTO(unsigned int type, unsigned int state, unsigned int cpu_id),
 
 	TP_ARGS(type, state, cpu_id)
-#else
-	TP_PROTO(unsigned int type, unsigned int state),
-
-	TP_ARGS(type, state)
-#endif
 )
 
 LTTNG_TRACEPOINT_EVENT_INSTANCE(power, power_frequency,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 	TP_PROTO(unsigned int type, unsigned int state, unsigned int cpu_id),
 
 	TP_ARGS(type, state, cpu_id)
-#else
-	TP_PROTO(unsigned int type, unsigned int state),
-
-	TP_ARGS(type, state)
-#endif
 )
 
 LTTNG_TRACEPOINT_EVENT(power_end,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 	TP_PROTO(unsigned int cpu_id),
 
 	TP_ARGS(cpu_id),
-#else
-	TP_PROTO(int dummy),
-
-	TP_ARGS(dummy),
-#endif
 
 	TP_FIELDS(
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
 		ctf_integer(u64, cpu_id, cpu_id)
-#else
-		ctf_integer(u64, dummy, 0xffff)
-#endif
 	)
 )
 
@@ -198,7 +160,7 @@ enum {
    events get removed */
 static inline void trace_power_start(u64 type, u64 state, u64 cpuid) {};
 static inline void trace_power_end(u64 cpuid) {};
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
 static inline void trace_power_start_rcuidle(u64 type, u64 state, u64 cpuid) {};
 static inline void trace_power_end_rcuidle(u64 cpuid) {};
 #endif
@@ -207,7 +169,6 @@ static inline void trace_power_frequency(u64 type, u64 state, u64 cpuid) {};
 
 #endif /* CONFIG_EVENT_POWER_TRACING_DEPRECATED */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 /*
  * The clock events are used for clock enable/disable and for
  *  clock rate change
@@ -274,7 +235,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(power_domain, power_domain_target,
 
 	TP_ARGS(name, state, cpu_id)
 )
-#endif
 
 #endif /* LTTNG_TRACE_POWER_H */
 
