@@ -27,10 +27,10 @@
 #include <linux/jhash.h>
 #include <linux/uaccess.h>
 #include <linux/vmalloc.h>
-#include <linux/uuid.h>
 #include <linux/dmi.h>
 
-#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_all() */
+#include <wrapper/uuid.h>
+#include <wrapper/vmalloc.h>	/* for wrapper_vmalloc_sync_mappings() */
 #include <wrapper/random.h>
 #include <wrapper/tracepoint.h>
 #include <wrapper/list.h>
@@ -130,7 +130,7 @@ struct lttng_session *lttng_session_create(void)
 		goto err;
 	INIT_LIST_HEAD(&session->chan);
 	INIT_LIST_HEAD(&session->events);
-	uuid_le_gen(&session->uuid);
+	lttng_guid_gen(&session->uuid);
 
 	metadata_cache = kzalloc(sizeof(struct lttng_metadata_cache),
 			GFP_KERNEL);
@@ -1622,7 +1622,7 @@ void lttng_session_lazy_sync_enablers(struct lttng_session *session)
  * was written and a negative value on error.
  */
 int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
-		struct channel *chan)
+		struct channel *chan, bool *coherent)
 {
 	struct lib_ring_buffer_ctx ctx;
 	int ret = 0;
@@ -1661,6 +1661,7 @@ int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
 	ret = stream->transport->ops.event_reserve(&ctx, 0);
 	if (ret != 0) {
 		printk(KERN_WARNING "LTTng: Metadata event reservation failed\n");
+		stream->coherent = false;
 		goto end;
 	}
 	stream->transport->ops.event_write(&ctx,
@@ -1668,18 +1669,43 @@ int lttng_metadata_output_channel(struct lttng_metadata_stream *stream,
 			reserve_len);
 	stream->transport->ops.event_commit(&ctx);
 	stream->metadata_in += reserve_len;
+	if (reserve_len < len || stream->metadata_cache->producing != 0)
+		stream->coherent = false;
+	else
+		stream->coherent = true;
 	ret = reserve_len;
 
 end:
+	if (coherent)
+		*coherent = stream->coherent;
 	mutex_unlock(&stream->metadata_cache->lock);
 	return ret;
 }
 
+static
+void lttng_metadata_begin(struct lttng_session *session)
+{
+	mutex_lock(&session->metadata_cache->lock);
+	session->metadata_cache->producing++;
+	mutex_unlock(&session->metadata_cache->lock);
+}
+
+static
+void lttng_metadata_end(struct lttng_session *session)
+{
+	mutex_lock(&session->metadata_cache->lock);
+	WARN_ON_ONCE(!session->metadata_cache->producing);
+	session->metadata_cache->producing--;
+	mutex_unlock(&session->metadata_cache->lock);
+}
+
 /*
  * Write the metadata to the metadata cache.
  * Must be called with sessions_mutex held.
  * The metadata cache lock protects us from concurrent read access from
  * thread outputting metadata content to ring buffer.
+ * The content of the printf is printed as a single atomic metadata
+ * transaction.
  */
 int lttng_metadata_printf(struct lttng_session *session,
 			  const char *fmt, ...)
@@ -1699,6 +1725,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 
 	len = strlen(str);
 	mutex_lock(&session->metadata_cache->lock);
+	session->metadata_cache->producing++;
 	if (session->metadata_cache->metadata_written + len >
 			session->metadata_cache->cache_alloc) {
 		char *tmp_cache_realloc;
@@ -1724,6 +1751,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 			session->metadata_cache->metadata_written,
 			str, len);
 	session->metadata_cache->metadata_written += len;
+	session->metadata_cache->producing--;
 	mutex_unlock(&session->metadata_cache->lock);
 	kfree(str);
 
@@ -1733,6 +1761,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 	return 0;
 
 err:
+	session->metadata_cache->producing--;
 	mutex_unlock(&session->metadata_cache->lock);
 	kfree(str);
 	return -ENOMEM;
@@ -2270,6 +2299,8 @@ int _lttng_fields_metadata_statedump(struct lttng_session *session,
 
 /*
  * Must be called with sessions_mutex held.
+ * The entire event metadata is printed as a single atomic metadata
+ * transaction.
  */
 static
 int _lttng_event_metadata_statedump(struct lttng_session *session,
@@ -2283,6 +2314,8 @@ int _lttng_event_metadata_statedump(struct lttng_session *session,
 	if (chan->channel_type == METADATA_CHANNEL)
 		return 0;
 
+	lttng_metadata_begin(session);
+
 	ret = lttng_metadata_printf(session,
 		"event {\n"
 		"	name = \"%s\";\n"
@@ -2332,12 +2365,15 @@ int _lttng_event_metadata_statedump(struct lttng_session *session,
 
 	event->metadata_dumped = 1;
 end:
+	lttng_metadata_end(session);
 	return ret;
 
 }
 
 /*
  * Must be called with sessions_mutex held.
+ * The entire channel metadata is printed as a single atomic metadata
+ * transaction.
  */
 static
 int _lttng_channel_metadata_statedump(struct lttng_session *session,
@@ -2351,6 +2387,8 @@ int _lttng_channel_metadata_statedump(struct lttng_session *session,
 	if (chan->channel_type == METADATA_CHANNEL)
 		return 0;
 
+	lttng_metadata_begin(session);
+
 	WARN_ON_ONCE(!chan->header_type);
 	ret = lttng_metadata_printf(session,
 		"stream {\n"
@@ -2384,6 +2422,7 @@ int _lttng_channel_metadata_statedump(struct lttng_session *session,
 
 	chan->metadata_dumped = 1;
 end:
+	lttng_metadata_end(session);
 	return ret;
 }
 
@@ -2571,6 +2610,9 @@ int _lttng_session_metadata_statedump(struct lttng_session *session)
 
 	if (!READ_ONCE(session->active))
 		return 0;
+
+	lttng_metadata_begin(session);
+
 	if (session->metadata_dumped)
 		goto skip_session;
 
@@ -2743,6 +2785,7 @@ skip_session:
 	}
 	session->metadata_dumped = 1;
 end:
+	lttng_metadata_end(session);
 	return ret;
 }
 
@@ -2753,9 +2796,9 @@ end:
  * Registers a transport which can be used as output to extract the data out of
  * LTTng. The module calling this registration function must ensure that no
  * trap-inducing code will be executed by the transport functions. E.g.
- * vmalloc_sync_all() must be called between a vmalloc and the moment the memory
+ * vmalloc_sync_mappings() must be called between a vmalloc and the moment the memory
  * is made visible to the transport function. This registration acts as a
- * vmalloc_sync_all. Therefore, only if the module allocates virtual memory
+ * vmalloc_sync_mappings. Therefore, only if the module allocates virtual memory
  * after its registration must it synchronize the TLBs.
  */
 void lttng_transport_register(struct lttng_transport *transport)
@@ -2763,9 +2806,9 @@ void lttng_transport_register(struct lttng_transport *transport)
 	/*
 	 * Make sure no page fault can be triggered by the module about to be
 	 * registered. We deal with this here so we don't have to call
-	 * vmalloc_sync_all() in each module's init.
+	 * vmalloc_sync_mappings() in each module's init.
 	 */
-	wrapper_vmalloc_sync_all();
+	wrapper_vmalloc_sync_mappings();
 
 	mutex_lock(&sessions_mutex);
 	list_add_tail(&transport->node, &lttng_transport_list);
