@@ -36,8 +36,8 @@
 #include <lttng-events.h>
 #include <lttng-tracer.h>
 #include <wrapper/irqdesc.h>
-#include <wrapper/spinlock.h>
 #include <wrapper/fdtable.h>
+#include <wrapper/namespace.h>
 #include <wrapper/irq.h>
 #include <wrapper/tracepoint.h>
 #include <wrapper/genhd.h>
@@ -55,47 +55,31 @@
 #define LTTNG_INSTRUMENTATION
 #include <instrumentation/events/lttng-module/lttng-statedump.h>
 
-LTTNG_DEFINE_TRACE(lttng_statedump_block_device,
-	TP_PROTO(struct lttng_session *session,
-		dev_t dev, const char *diskname),
-	TP_ARGS(session, dev, diskname));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_end,
-	TP_PROTO(struct lttng_session *session),
-	TP_ARGS(session));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_interrupt,
-	TP_PROTO(struct lttng_session *session,
-		unsigned int irq, const char *chip_name,
-		struct irqaction *action),
-	TP_ARGS(session, irq, chip_name, action));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_file_descriptor,
-	TP_PROTO(struct lttng_session *session,
-		struct task_struct *p, int fd, const char *filename,
-		unsigned int flags, fmode_t fmode),
-	TP_ARGS(session, p, fd, filename, flags, fmode));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_start,
-	TP_PROTO(struct lttng_session *session),
-	TP_ARGS(session));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_process_state,
-	TP_PROTO(struct lttng_session *session,
-		struct task_struct *p,
-		int type, int mode, int submode, int status,
-		struct pid_namespace *pid_ns),
-	TP_ARGS(session, p, type, mode, submode, status, pid_ns));
-
-LTTNG_DEFINE_TRACE(lttng_statedump_network_interface,
-	TP_PROTO(struct lttng_session *session,
-		struct net_device *dev, struct in_ifaddr *ifa),
-	TP_ARGS(session, dev, ifa));
+DEFINE_TRACE(lttng_statedump_block_device);
+DEFINE_TRACE(lttng_statedump_end);
+DEFINE_TRACE(lttng_statedump_interrupt);
+DEFINE_TRACE(lttng_statedump_file_descriptor);
+DEFINE_TRACE(lttng_statedump_start);
+DEFINE_TRACE(lttng_statedump_process_state);
+DEFINE_TRACE(lttng_statedump_process_pid_ns);
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,6,0))
+DEFINE_TRACE(lttng_statedump_process_cgroup_ns);
+#endif
+DEFINE_TRACE(lttng_statedump_process_ipc_ns);
+#ifndef LTTNG_MNT_NS_MISSING_HEADER
+DEFINE_TRACE(lttng_statedump_process_mnt_ns);
+#endif
+DEFINE_TRACE(lttng_statedump_process_net_ns);
+DEFINE_TRACE(lttng_statedump_process_user_ns);
+DEFINE_TRACE(lttng_statedump_process_uts_ns);
+DEFINE_TRACE(lttng_statedump_network_interface);
+#ifdef LTTNG_HAVE_STATEDUMP_CPU_TOPOLOGY
+DEFINE_TRACE(lttng_statedump_cpu_topology);
+#endif
 
 struct lttng_fd_ctx {
 	char *page;
 	struct lttng_session *session;
-	struct task_struct *p;
 	struct files_struct *files;
 };
 
@@ -136,116 +120,6 @@ enum lttng_process_status {
 	LTTNG_DEAD = 7,
 };
 
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,11,0))
-
-#define LTTNG_PART_STRUCT_TYPE struct block_device
-
-static
-int lttng_get_part_name(struct gendisk *disk, struct block_device *part, char *name_buf)
-{
-	const char *p;
-
-	p = bdevname(part, name_buf);
-	if (!p)
-		return -ENOSYS;
-
-	return 0;
-}
-
-static
-dev_t lttng_get_part_devt(struct block_device *part)
-{
-	return part->bd_dev;
-}
-
-#else
-
-#define LTTNG_PART_STRUCT_TYPE struct hd_struct
-
-static
-int lttng_get_part_name(struct gendisk *disk, struct hd_struct *part, char *name_buf)
-{
-	const char *p;
-	struct block_device bdev;
-
-	/*
-	 * Create a partial 'struct blockdevice' to use
-	 * 'bdevname()' which is a simple wrapper over
-	 * 'disk_name()' but has the honor to be EXPORT_SYMBOL.
-	 */
-	bdev.bd_disk = disk;
-	bdev.bd_part = part;
-
-	p = bdevname(&bdev, name_buf);
-	if (!p)
-		return -ENOSYS;
-
-	return 0;
-}
-
-static
-dev_t lttng_get_part_devt(struct hd_struct *part)
-{
-	return part_devt(part);
-}
-#endif
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,12,0))
-static
-int lttng_statedump_each_block_device(struct lttng_session *session, struct gendisk *disk)
-{
-	struct block_device *part;
-	unsigned long idx;
-	int ret = 0;
-
-	/* Include partition 0 */
-	idx = 0;
-
-	rcu_read_lock();
-	xa_for_each(&disk->part_tbl, idx, part) {
-		char name_buf[BDEVNAME_SIZE];
-
-		/* Exclude non-partitions bdev and empty partitions. */
-		if (bdev_is_partition(part) && !bdev_nr_sectors(part))
-			continue;
-
-		if (lttng_get_part_name(disk, part, name_buf) == -ENOSYS) {
-			ret = -ENOSYS;
-			goto end;
-		}
-		trace_lttng_statedump_block_device(session, lttng_get_part_devt(part),
-				name_buf);
-	}
-end:
-	rcu_read_unlock();
-	return ret;
-}
-#else
-static
-int lttng_statedump_each_block_device(struct lttng_session *session, struct gendisk *disk)
-{
-	struct disk_part_iter piter;
-	LTTNG_PART_STRUCT_TYPE *part;
-
-	disk_part_iter_init(&piter, disk, DISK_PITER_INCL_PART0);
-
-	while ((part = disk_part_iter_next(&piter))) {
-		char name_buf[BDEVNAME_SIZE];
-
-		if (lttng_get_part_name(disk, part, name_buf) == -ENOSYS) {
-			disk_part_iter_exit(&piter);
-			return -ENOSYS;
-		}
-		trace_lttng_statedump_block_device(session, lttng_get_part_devt(part),
-				name_buf);
-	}
-	disk_part_iter_exit(&piter);
-
-	return 0;
-}
-#endif
-
 static
 int lttng_enumerate_block_devices(struct lttng_session *session)
 {
@@ -253,21 +127,19 @@ int lttng_enumerate_block_devices(struct lttng_session *session)
 	struct device_type *ptr_disk_type;
 	struct class_dev_iter iter;
 	struct device *dev;
-	int ret = 0;
 
 	ptr_block_class = wrapper_get_block_class();
-	if (!ptr_block_class) {
-		ret = -ENOSYS;
-		goto end;
-	}
+	if (!ptr_block_class)
+		return -ENOSYS;
 	ptr_disk_type = wrapper_get_disk_type();
 	if (!ptr_disk_type) {
-		ret = -ENOSYS;
-		goto end;
+		return -ENOSYS;
 	}
 	class_dev_iter_init(&iter, ptr_block_class, NULL, ptr_disk_type);
 	while ((dev = class_dev_iter_next(&iter))) {
+		struct disk_part_iter piter;
 		struct gendisk *disk = dev_to_disk(dev);
+		struct hd_struct *part;
 
 		/*
 		 * Don't show empty devices or things that have been
@@ -277,11 +149,24 @@ int lttng_enumerate_block_devices(struct lttng_session *session)
 		    (disk->flags & GENHD_FL_SUPPRESS_PARTITION_INFO))
 			continue;
 
-		ret = lttng_statedump_each_block_device(session, disk);
+		disk_part_iter_init(&piter, disk, DISK_PITER_INCL_PART0);
+		while ((part = disk_part_iter_next(&piter))) {
+			char name_buf[BDEVNAME_SIZE];
+			char *p;
+
+			p = wrapper_disk_name(disk, part->partno, name_buf);
+			if (!p) {
+				disk_part_iter_exit(&piter);
+				class_dev_iter_exit(&iter);
+				return -ENOSYS;
+			}
+			trace_lttng_statedump_block_device(session,
+					part_devt(part), name_buf);
+		}
+		disk_part_iter_exit(&piter);
 	}
 	class_dev_iter_exit(&iter);
-end:
-	return ret;
+	return 0;
 }
 
 #ifdef CONFIG_INET
@@ -359,52 +244,50 @@ int lttng_dump_one_fd(const void *p, struct file *file, unsigned int fd)
 
 		/* Make sure we give at least some info */
 		spin_lock(&dentry->d_lock);
-		trace_lttng_statedump_file_descriptor(ctx->session, ctx->p, fd,
-			dentry->d_name.name, flags, file->f_mode);
+		trace_lttng_statedump_file_descriptor(ctx->session,
+			ctx->files, fd, dentry->d_name.name, flags,
+			file->f_mode);
 		spin_unlock(&dentry->d_lock);
 		goto end;
 	}
-	trace_lttng_statedump_file_descriptor(ctx->session, ctx->p, fd, s,
-		flags, file->f_mode);
+	trace_lttng_statedump_file_descriptor(ctx->session,
+		ctx->files, fd, s, flags, file->f_mode);
 end:
 	return 0;
 }
 
+/* Called with task lock held. */
 static
-void lttng_enumerate_task_fd(struct lttng_session *session,
-		struct task_struct *p, char *tmp)
+void lttng_enumerate_files(struct lttng_session *session,
+		struct files_struct *files,
+		char *tmp)
 {
-	struct lttng_fd_ctx ctx = { .page = tmp, .session = session, .p = p };
-	struct files_struct *files;
+	struct lttng_fd_ctx ctx = { .page = tmp, .session = session, .files = files, };
 
-	task_lock(p);
-	files = p->files;
-	if (!files)
-		goto end;
-	ctx.files = files;
 	lttng_iterate_fd(files, 0, lttng_dump_one_fd, &ctx);
-end:
-	task_unlock(p);
 }
 
+#ifdef LTTNG_HAVE_STATEDUMP_CPU_TOPOLOGY
 static
-int lttng_enumerate_file_descriptors(struct lttng_session *session)
+int lttng_enumerate_cpu_topology(struct lttng_session *session)
 {
-	struct task_struct *p;
-	char *tmp;
+	int cpu;
+	const cpumask_t *cpumask = cpu_possible_mask;
 
-	tmp = (char *) __get_free_page(GFP_KERNEL);
-	if (!tmp)
-		return -ENOMEM;
+	for (cpu = cpumask_first(cpumask); cpu < nr_cpu_ids;
+			cpu = cpumask_next(cpu, cpumask)) {
+		trace_lttng_statedump_cpu_topology(session, &cpu_data(cpu));
+	}
 
-	/* Enumerate active file descriptors */
-	rcu_read_lock();
-	for_each_process(p)
-		lttng_enumerate_task_fd(session, p, tmp);
-	rcu_read_unlock();
-	free_page((unsigned long) tmp);
 	return 0;
 }
+#else
+static
+int lttng_enumerate_cpu_topology(struct lttng_session *session)
+{
+	return 0;
+}
+#endif
 
 #if 0
 /*
@@ -456,10 +339,6 @@ int lttng_enumerate_vm_maps(struct lttng_session *session)
 
 #ifdef CONFIG_LTTNG_HAS_LIST_IRQ
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,39))
-#define irq_desc_get_chip(desc) get_irq_desc_chip(desc)
-#endif
-
 static
 int lttng_list_interrupts(struct lttng_session *session)
 {
@@ -475,12 +354,12 @@ int lttng_list_interrupts(struct lttng_session *session)
 			irq_desc_get_chip(desc)->name ? : "unnamed_irq_chip";
 
 		local_irq_save(flags);
-		wrapper_desc_spin_lock(&desc->lock);
+		raw_spin_lock(&desc->lock);
 		for (action = desc->action; action; action = action->next) {
 			trace_lttng_statedump_interrupt(session,
 				irq, irq_chip_name, action);
 		}
-		wrapper_desc_spin_unlock(&desc->lock);
+		raw_spin_unlock(&desc->lock);
 		local_irq_restore(flags);
 	}
 	return 0;
@@ -495,6 +374,10 @@ int lttng_list_interrupts(struct lttng_session *session)
 #endif
 
 /*
+ * Statedump the task's namespaces using the proc filesystem inode number as
+ * the unique identifier. The user and pid ns are nested and will be dumped
+ * recursively.
+ *
  * Called with task lock held.
  */
 static
@@ -505,23 +388,87 @@ void lttng_statedump_process_ns(struct lttng_session *session,
 		enum lttng_execution_submode submode,
 		enum lttng_process_status status)
 {
+	struct nsproxy *proxy;
 	struct pid_namespace *pid_ns;
+	struct user_namespace *user_ns;
 
+	/*
+	 * The pid and user namespaces are special, they are nested and
+	 * accessed with specific functions instead of the nsproxy struct
+	 * like the other namespaces.
+	 */
 	pid_ns = task_active_pid_ns(p);
 	do {
-		trace_lttng_statedump_process_state(session,
-			p, type, mode, submode, status, pid_ns);
+		trace_lttng_statedump_process_pid_ns(session, p, pid_ns);
 		pid_ns = pid_ns ? pid_ns->parent : NULL;
 	} while (pid_ns);
+
+
+	user_ns = task_cred_xxx(p, user_ns);
+	do {
+		trace_lttng_statedump_process_user_ns(session, p, user_ns);
+		/*
+		 * trace_lttng_statedump_process_user_ns() internally
+		 * checks whether user_ns is NULL. While this does not
+		 * appear to be a possible return value for
+		 * task_cred_xxx(), err on the safe side and check
+		 * for NULL here as well to be consistent with the
+		 * paranoid behavior of
+		 * trace_lttng_statedump_process_user_ns().
+		 */
+		user_ns = user_ns ? user_ns->lttng_user_ns_parent : NULL;
+	} while (user_ns);
+
+	/*
+	 * Back and forth on locking strategy within Linux upstream for nsproxy.
+	 * See Linux upstream commit 728dba3a39c66b3d8ac889ddbe38b5b1c264aec3
+	 * "namespaces: Use task_lock and not rcu to protect nsproxy"
+	 * for details.
+	 */
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,17,0) || \
+		LTTNG_UBUNTU_KERNEL_RANGE(3,13,11,36, 3,14,0,0) || \
+		LTTNG_UBUNTU_KERNEL_RANGE(3,16,1,11, 3,17,0,0) || \
+		LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,13,0, 3,11,0,0,0,0))
+	proxy = p->nsproxy;
+#else
+	rcu_read_lock();
+	proxy = task_nsproxy(p);
+#endif
+	if (proxy) {
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,6,0))
+		trace_lttng_statedump_process_cgroup_ns(session, p, proxy->cgroup_ns);
+#endif
+		trace_lttng_statedump_process_ipc_ns(session, p, proxy->ipc_ns);
+#ifndef LTTNG_MNT_NS_MISSING_HEADER
+		trace_lttng_statedump_process_mnt_ns(session, p, proxy->mnt_ns);
+#endif
+		trace_lttng_statedump_process_net_ns(session, p, proxy->net_ns);
+		trace_lttng_statedump_process_uts_ns(session, p, proxy->uts_ns);
+	}
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,17,0) || \
+		LTTNG_UBUNTU_KERNEL_RANGE(3,13,11,36, 3,14,0,0) || \
+		LTTNG_UBUNTU_KERNEL_RANGE(3,16,1,11, 3,17,0,0) || \
+		LTTNG_RHEL_KERNEL_RANGE(3,10,0,229,13,0, 3,11,0,0,0,0))
+	/* (nothing) */
+#else
+	rcu_read_unlock();
+#endif
 }
 
 static
 int lttng_enumerate_process_states(struct lttng_session *session)
 {
 	struct task_struct *g, *p;
+	char *tmp;
+
+	tmp = (char *) __get_free_page(GFP_KERNEL);
+	if (!tmp)
+		return -ENOMEM;
 
 	rcu_read_lock();
 	for_each_process(g) {
+		struct files_struct *prev_files = NULL;
+
 		p = g;
 		do {
 			enum lttng_execution_mode mode =
@@ -530,6 +477,7 @@ int lttng_enumerate_process_states(struct lttng_session *session)
 				LTTNG_UNKNOWN;
 			enum lttng_process_status status;
 			enum lttng_thread_type type;
+			struct files_struct *files;
 
 			task_lock(p);
 			if (p->exit_state == EXIT_ZOMBIE)
@@ -564,13 +512,31 @@ int lttng_enumerate_process_states(struct lttng_session *session)
 				type = LTTNG_USER_THREAD;
 			else
 				type = LTTNG_KERNEL_THREAD;
+			files = p->files;
+
+			trace_lttng_statedump_process_state(session,
+				p, type, mode, submode, status, files);
 			lttng_statedump_process_ns(session,
 				p, type, mode, submode, status);
+			/*
+			 * As an optimisation for the common case, do not
+			 * repeat information for the same files_struct in
+			 * two consecutive threads. This is the common case
+			 * for threads sharing the same fd table. RCU guarantees
+			 * that the same files_struct pointer is not re-used
+			 * throughout processes/threads iteration.
+			 */
+			if (files && files != prev_files) {
+				lttng_enumerate_files(session, files, tmp);
+				prev_files = files;
+			}
 			task_unlock(p);
 		} while_each_thread(g, p);
 	}
 	rcu_read_unlock();
 
+	free_page((unsigned long) tmp);
+
 	return 0;
 }
 
@@ -589,9 +555,6 @@ int do_lttng_statedump(struct lttng_session *session)
 
 	trace_lttng_statedump_start(session);
 	ret = lttng_enumerate_process_states(session);
-	if (ret)
-		return ret;
-	ret = lttng_enumerate_file_descriptors(session);
 	if (ret)
 		return ret;
 	/*
@@ -616,6 +579,9 @@ int do_lttng_statedump(struct lttng_session *session)
 	default:
 		return ret;
 	}
+	ret = lttng_enumerate_cpu_topology(session);
+	if (ret)
+		return ret;
 
 	/* TODO lttng_dump_idt_table(session); */
 	/* TODO lttng_dump_softirq_vec(session); */
